# HL History - 1

The course code for this page is **CHW3MZ**.

## Command terms

The following terms are regularly used by IB and have specific meanings:

 - **Analyse**: Break down an idea into its essential elements
 - **Compare**: Identify and justify the similarities between ideas
 - **Contrast**: Identify and justify the differences between ideas
 - **Discuss**: Provide a balanced review with a range of justified opinions or conclusions
 - **Evaluate**: Appraise an argument with strengths and limitations
 - **Examine**: Consider an argument or concept, revealing its assumptions and interrelations
 - **To what extent**: Consider the merits and demerits of an idea or argument with justified opinions or conclusions

## Historiography

Historiography is the study of how history is developed and how historians have viewed history. It helps develop the ability to view events from multiple perspectives and reveals how others might view events in multiple perspectives. The **historical method** outlines the process of making history from start to finish:

 - **Questions are asked** about any of the following:
	- major/minor long-/short-term **causes** of an event
	- the **nature** of an event — the purpose of the event, the status of the event
	- the immediate/long-term/short-term **impacts** of an event
	- the **ethics** of an event
	- a hypothetical **counterfactual** version of an event
 - **Data is collected** to help answer the questions
 - **Data is analysed** to identify patterns and trends via statistics, make judgements using OPCVL, and make comparisons of the main message (content) and PERMS (political, economical, religious, military, social)
 - **Arguments are created** with a thesis and critical analyses per argument
 - and the **findings are communicated** via any means, including essays, opinion paragraphs, debates, presentations, music, etc.

### Lenses

There are seven main schools of thought historians usually fall under that attempt to explain why history happens.

 - The **great people** lens views history with the perspective that individuals create changes, and without those individuals history would be drastically altered. This school focuses on their individual motivations, relationships, etc.
 - The **structuralist** lens views history and events as caused by changes in economic structures, technology, ideology, and social norms.
 - The **decisionist** lens views history with the perspective that it is the decisions of people that are the cause of events.
 - The **Marxist** lens focuses on class conflict — the exploiter and the exploitee and how their conflicts affect history.
 - The **Toynbee** lens regards the response of people to crises as the largest cause to historical events.
 - The **post-modern** lens states that history reflects the time period it was written in and the intent of the author. This school asserts that there is no historical truth and focuses on how history is shaped and manipulated to serve the agendas and needs of various civilisations.
 - The **feminist** lens states that history should reflect the experience of both genders equally. This school particularly focuses on the treatment of and lives of women.

### Historical concepts

There are six key historical concepts that should be taken under consideration in the analysis of history.

 - **Change**: how people and events create change, the differences before and after an event, and the nature and pace of the change
 - **Continuity**: what doesn't change and to what extent things don't change
 - **Causation**: why an event occurred (social, economic, political, etc.), and what factor(s) caused it
 - **Consequence**: the long- and short-term effects of an event on society
 - **Significance**: why the event matters and the importance of some details over others
 - **Perspective**: the different perspectives, why there are different perspectives, and how those perspectives affect the interpretation of history

### Data collection

The abundance of **diverse** data allows for greater perspectives to be gleaned and thus more solutions to a problem. Data and their sources can fall under one of three categories:

 - **Primary** data is from an original source with no sources under it — e.g., newspapers, memoirs, photographs, diaries, etc.
 - **Secondary** data is an interpretation of a primary source(s) with its own argument — e.g., articles, thesises, documentaries, etc.
 - **Tertiary** data compiles secondary sources and should only be used for context — e.g., wikis, textbooks, encyclopedias, etc.

### Logic

!!! definition
    - **Logic** is the study of rules of inference and the analysis of arguments.
    - A **conclusion** is a proposition that follows all others.
    - An **inference** is a connection that acts as a logical leap between a premise and a conclusion.
    - **Logically consistent** statements follow the three laws of thought and do not contradict.
    - **Logically contradicting** statements do not follow the three laws of thought.
    - The **validity** of a statement is its correctness of reasoning via the laws of thought.
    - A **sound** argument is of valid form and has a true premise.
    - An **argument** is a simple statement or disagreement that attempts to reach a conclusion by proving something true with evidence. Good arguments are sound, valid, clear, and avoids hasty conclusions.

**Aristotle** laid the foundations for the principles of formal logic via the three laws of thought.

 - **Law of identity**: everything is identical with itself.
 - **Law of noncontradiction**: contradictory statements cannot both be true.
 - **Law of excluded middle**: any proposition must either be true or false.

!!! example
    - Identity: A football is a football.
    - Noncontradiction: If water and oil do not mix, and substance A mixes in water, it must not be oil.
    - Excluded middle: The Nintendo Switch must either be or not be a potato.

**Deductive** arguments connect a general statement to a more specific statement based on laws, rules, and/or widely accepted principles.

!!! example
    As monkeys like bananas and Lucy is a monkey, Lucy must like bananas.

**Inductive** arguments connect a specific statement to a more general statement based on **empiric** data.

!!! example
    As three of the eight billion humans on Earth are mortal, all humans must be mortal.

### Logical fallacies

 - An **ad hominem** argument attacks the arguer or anything else instead of the argument.
    - e.g., *"You're a Nintendo fanboy; of course you think that."*
 - Arguments that **appeal to authority** use the opinion of an authority on a topic is used as evidence to support an argument.
    - e.g., *"The President of the United States said that we should inject disinfectant into ourselves, so it must be a good idea!"*
 - Arguments that **appeal to emotion** manipulate the recipient's emotions typically via loaded language to win an argument.
    - e.g., *"Those island devils have robbed us of our sleep at night — they must be eradicated!"*
 - Arguments that **appeal to force** use threats to win an argument.
    - e.g., *"I'm right, aren't I?" said the jock, flexing her biceps threateningly.*
 - Arguments that **appeal to ignorance** assert a proposition is true because it has not been proven false.
    - e.g., *"My laptop must secretly have chips in it that no one can detect from aliens because we don't know if there* aren't *undetectable chips in there."*
 - **Bandwagoning or herding** arguments assert that a conclusion is true because it is accepted by most people. This is a result of confirmation bias.
    - e.g., *"Ma, everyone else is jumping off that bridge, so why shouldn't I?"*
 - A fallacy of **accident** wrongly applies a general rule to a specific exception.
    - e.g., *Since surgeons cut people with knives and cutting people with knives is a crime, surgeons are criminals.*
 - An argument that **begs the question** has circular reasoning by having premises that assume its conclusion.
    - e.g., *Acid must be able to eat through your skin because it is corrosive.*
 - **Cherry picking** occurs when evidence that supports the conclusion is pointed out while those that contradict the conclusion are ignored or withheld.
    - e.g., *"Look at these perfect cherries — their tree must be in perfect condition!"*
 - A fallacy of **converse accident** wrongly applies a specific exception to a general rule.
    - e.g., *As the Nintendo Switch, a game console, is portable, all game consoles must be portable.*
 - A **complex question**, also known as a trick question,  embeds a proposition that is accepted when a direct answer is given to the question.
    - e.g., *Have you stopped abusing children yet?*
 - Arguments with a **false cause** incorrectly assume a cause to an effect.
    - e.g., imagining correlation implies causation.
 - **Hasty generalisations** appear in inductive generalisations based on insufficient evidence.
    - e.g., *Since the first seven odd numbers are prime or square, all odd numbers must be prime or square.*
 - Arguments that **miss the point** provide an irrelevant conclusion that fails to address the issue of the question.
    - e.g., *"Is it allowed?" "It should be allowed because it's nowhere near as bad as alcohol."*
 - A **non sequitur** is an invalid argument that does not follow the laws of thought.
    - e.g., *All humans are mammals. Whales are mammals. Therefore, whales are humans.*
 - A **no true Scotsman** (appeal to purity) fallacy takes a generalisation and doubles down to protect it by excluding counterexamples typically via emotionally charged language.
    - e.g., *"Although your father is a Scotsman and dances, no* true *Scotsman would dance."*
 - Arguments with **recency bias** put greater importance on recent data over historic data.
    - e.g., *As GameStop's stock has risen over the past few days dramatically, it will continue to do so.*
 - **Red herrings** change the issue of subject away from the original question.
    - e.g., *You should support the new housing bill. We can't continue to see people living in the streets; we must have cheaper housing.*
 - A **straw man** argument misrepresents the opposing position by making their arguments sound more extreme.
    - e.g., *"We should relax laws on immigration." "The instant we let millions of people through our border is when our country falls."*

## Causes of the Chinese Civil War

### Decline of the Manchu Qing Dynasty
**— Long-term structural political**

In the Qing dynasty, from 1861 to 1908, Empress **Cixi** ruled China as an autocrat. Corruption was rampant in Beijing and officials could not control warlords in remote regions. Under Cixi, China became weak and was easily influenced by foreign powers.

### Foreign involvement
**— Long-term structural political**

The influence of foreign powers increased outrage among citizens at the inability of the government to do things and led to greater internal dissent.

The **opium wars** starting from 1839 were two armed conflicts in China between Western powers and the Qing dynasty. Both were won easily by the West due to their superior, more modern military technology. This resulted in China signing a series of what came to be known as "**unfair treaties**" starting with the Treaty of Nanjing in 1842, which ended the First Opium War and gave Hong Kong to Britain "in perpetuity" among other trading concessions.

The **First Sino-Japanese War** (also known as the War or Jiawu) in 1894–1895 also resulted in Japan's easy victory due to obsolete Chinese military technology.

!!! example
    During the First Sino-Japanese War, Cixi took military money and spent it on palace renovations, demonstrating the corruption in and ineffectiveness of the regime.

### Outdated agricultural practices and limited industrial development
**— Long-term structural economic**

!!! context
    In 1900, Japan and the United States were major industrial powers and both were steadily modernising.

China's rulers believed that Westerners were barbarians and that nothing could be learned from industrialisation. This contributed to their weak military strength as they fell further behind other countries.

!!! example
    By 1914, only ~6 000 km of rail was laid in China while the US had laid ~225 000 km.

Additionally, the population boom meant that demand for food increased, but outdated agricultural practices and technologies could not keep up, resulting in famine.

### Tradition and class structure
**— Long-term structural social**

China operated under a **patriarchy** and had traditions and practices which were thought to be even at the time to be cruel and outdated especially for women.

!!! example
    The life expectancy of a city in China (Shenyang, Daoyi) from 1792 to 1867 was less than 40 years for men and about 30 for women.

**Submission to the Qing dynasty** was traditional as well — the Chinese could not marry Manchus nor live in Manchuria.

!!! example
    Men were required to wear a queue (a long pigtail behind a shaven forehead) to show subservience to the Manchu Empire.

The **class structure** in China did not change for hundreds of years and old traditions and practices persisted into the 1900s.

 - The land peasants worked on belonged to local landlords.
 - 80% of the population remained peasants.
 - Landlords took a large amount of crops as rent and the government also took a large portion as taxes.
 - The burdens from landlords and the government were compounded with natural disasters such as floods and droughts, resulting in famine.
 - Landlords could taken peasant women as they wished, force peasants to perform extra duties, and beat them if they were questioned.

### Internal dissent
**— Long-term structural political**

The **Taiping Civil War** from 1850 to 1864 was one of the bloodiest wars ever and the largest conflict of the 19th century. Anti-Manchurian sentiment was high as the people did not like that the Qing dynasty was ruled not by themselves. At the time, they could not marry Manchus, could not settle in Manchuria, and men were required to wear queues as a reminder of submission to Qing rule.

The **Boxer Rebellion** from 1899 to 1901 was caused by an organisation known as the Boxers (due to many of their members practising Chinese martial arts) desiring an end to foreign control in China. To do so, they violenced across northern China targeting foreign property, Christian missionaries, and Chinese Christians. Although initially supported by Cixi, support was split in the country and eventually she accepted help from foreign armies to end the rebellion.

!!! example
    The slogan of the Boxers was to "support the Qing government and exterminate foreigners".

### Introduction of progressive ideas and rise of revolutionaries

Sun Yixian

### 1911 revolution

failure of revolution
aftermath of revolution

### Warlords
**— Short-term**

warlords

### Rise of revolutionaries 2: electric boogaloo
**— Short-term**

first united front

screw this history too hard

## Mao's foreign policy

!!! definition
    **Sinocentrism** is the idea that China is the cultural, political, and/or economic centre of the world.

Mao was concentrated on maintaining and consolidating his power in China, but he supported the idea of an **international communist revolution** and focused on re-establishing China's position as a great power in the world.

After [Joseph Stalin](https://en.wikipedia.org/wiki/Joseph_Stalin)'s death, Mao was seen by many to be the leader of the communist world.

!!! example
    In 1964, China detonated its first nuclear bomb, claiming its necessity for defense and in opposing the "US imperialist policy of nuclear blackmail and nuclear threats". Originally advocating for the abolishment of nuclear weapons but blocked by the US, evidence seems to suggest that Mao was quite willing to use nuclear weapons, believing that China's population would recover quickly.

### Sino-Soviet relations

China's relationship with the USSR started off well enough but steadily deteriorated by the 1960s.

#### Treaty of Friendship, Alliance, and Mutual Assistance

On 16 December 1949, Mao took his first trip abroad to Moscow only a few months after the establishment of the PRC. He was not met with great enthusiasm — Soviet leaders would meet him but would not drink or eat lunch with him, and there were no celebrations upon his arrival. He was in essence treated like a minor politician from a small communist country.

The visit lasted three months and culminated in the signing of the treaty on 14 February 1950. In the [Sino-Soviet Treaty of Friendship, Alliance, and Mutual Assistance](https://en.wikipedia.org/wiki/Sino-Soviet_Treaty_of_Friendship,_Alliance_and_Mutual_Assistance), the USSR:

 - recognised the People's Republic of China as the legitimate government of China
 - lent $300 million to aid economic and logistic recovery from a decade of warfare

After the signing of the treaty, from 1953 to 1956, the USSR also sent 1 300+ economic and military advisers which were paid for by the PRC.

#### Korean War

!!! background
    From 1910 to August 1945, Korea was occupied by imperial Japan. After the end of World War II, the USSR and the US agreed to temporarily divide Korea along the 38th parallel and established a communist government in the north and a democratic government in the south, respectively.
    <center><img src="/resources/images/korea-map.png" width=350></img></center>
    (Source: Kognity)

Under a desire to unify Korea under communism, North Korean leader [Kim Il-Sung](https://en.wikipedia.org/wiki/Kim_Il-sung) asked Stalin for approval to attack South Korea but was denied due to the [Berlin Blockade](https://en.wikipedia.org/wiki/Berlin_Blockade) at the time. His approval was granted later in April 1950 and the surprise attack launched on 25 June 1950, capturing important cities such as Seoul.

In response, the [United Nations Security Council](https://en.wikipedia.org/wiki/United_Nations_Security_Council) declared North Korea as the aggressor and sent troops from 15 countries led by the US to restore peace under American general [Douglas MacArthur](https://en.wikipedia.org/wiki/Douglas_MacArthur), successfully retaking the 38th parallel.

!!! info
    - The UN motion to send troops only succeeded because the Soviet delegate with [veto powers](https://en.wikipedia.org/wiki/United_Nations_Security_Council_veto_power) was absent as a protest against UN refusal to accept the PRC as the legitimate government of China.
    - The United States, South Korea, and other nations sent 350 000, 400 000, and 50 000 troops, respectively.

!!! background
    - North Korea made significant contributions to the CCP during their liberation of mainland China.
    - Sino-American relations during this time period were especially poor due to the Truman administration declaring their support for the Republic of China on Taiwan as the "main China".

When UN forces crossed the Yalu River on the China-Korea border, Mao felt China's security was at stake and also recognised an opportunity to assert power. Additionally, concern over border security with a hostile east due to a revived Japan, a desire to replace the Soviet influence in North Korea with their own, and Stalin pressing Mao to assist in the war led China to intervene.

In October 1950, the [Chinese People's Volunteers](https://en.wikipedia.org/wiki/People%27s_Volunteer_Army) — in actuality a group of forces from the main People's Liberation Army under a different name to avoid official war with the US — deployed 500 000 troops push the UN troops back to the 38th parallel, resulting in a stalemate back at status quo by 1951. Talks lasted two years with US President [Eisenhower](https://en.wikipedia.org/wiki/Dwight_D._Eisenhower) threatening the use of nuclear weapons should they drag on until an [**armistice**](https://en.wikipedia.org/wiki/Korean_Armistice_Agreement) was signed on 27 July 1953.

???+ info
    **Casualties in the Korean War**
    <img src="/resources/images/korean-war-casualties.png" width=500>(Source: Kognity)</img>

From China's perspective, the war was both a success and a failure. Mao propagandised the war as a total success in their aim to "Resist America and Defend Korea".

| Success | Failure |
| --- | --- |
| Mao gained considerable prestige for being able to fight the US to a standstill | Heavy casualties — Mao's eldest son was killed in an air raid |
| North Korea remained communist | Sino-American relations deteriorated further, and China faced a total embargo from the US |
| China preserved its Manchurian border where its heavy industry was concentrated | The USSR-lent military equipment had to be repaid |

#### Sino-Soviet split

Stalin and Mao's relationship was tense, and the relationship between the two countries deteriorated much faster under [Nikita Khrushchev](https://en.wikipedia.org/wiki/Nikita_Khrushchev).

!!! background
    The border between the Soviet Union and China was determined by many treaties signed by various officials over many years. This left many gray areas where both countries claimed soverignity.

**Border conflicts** in 1969 between the two countries led to seven months of unofficial conflicts and border clashes over various islands and rivers. At this point in time, both countries had nuclear weapons. Tensions persisted until September 1969 when the Chinese Premier and Soviet Minister of Foreign Affairs met in Beijing in September 1969.

**Personality and ideological conflicts** between the leaders and countries worsened relations. Mao acted like an obedient student and never openly contradicted Stalin while he was in power but was often annoyed by his level of control over the CCP. Stalin was annoyed by Mao's attitude but needed a strong ally.

!!! example
    - In 1921, Mao believed that the rural population would lead China to revolution while Stalin interpreted that the proletariat could only be urban workers.
    - After the end of World War II, Stalin requested Mao to work with the GMD, but Mao decided to wipe out the party and take power instead.

In 1956, after Stalin's death, Khrushchev gave a [secret speech](https://en.wikipedia.org/wiki/On_the_Cult_of_Personality_and_Its_Consequences) denouncing his rule. Mao was alarmed by the brutality of these attacks and interpreted the speech as criticism against him and his own leadership in China.

!!! definition
    - **Détente** between the US and Soviet Union was the relaxation of strained relations between the two countries.
    - **Revisionism** in this context is the betrayal of original revolutionary ideas.
    - **Peaceful coexistence** is the belief that both capitalist and communist nations can exist together without war.

In 1957, Khrushchev organised a [conference in Moscow](https://en.wikipedia.org/wiki/1957_International_Meeting_of_Communist_and_Workers_Parties), inviting all communist states including China. Mao complained about Khrushchev's [revisionist](https://en.wikipedia.org/wiki/Revisionism_(Marxism)) and [peaceful coexistence](https://en.wikipedia.org/wiki/Peaceful_coexistence)/[detente](https://en.wikipedia.org/wiki/D%C3%A9tente) approaches with the United States. Mao believed that it was the duty of communists to conduct class warfare and that the Soviet Union was being too soft on the West by making concessions — they were not fit to lead the communist world. He thought that a final violent conflict was needed with capitalism.

In 1958, Khrushchev was invited to visit China and Mao treated him with disdain, aiming to make his visit unpleasant: the Soviet delegation was placed in a hotel with no AC, Mao invited Khrushchev to swim in his private pool — aware of his inability to swim, and refused any proposals for military cooperation and defense initiatives. In response, Khrushchev pulled most advisors out from China and removed all of them by 1960.

**Chinese meddling in Soviet international affairs** resulted in open defiance against the USSR. Unimpressed with de-Stalinisation, when Albania left the USSR in 1961, China supported them against the Soviet Union, pouring money into the country. In return, Albanian leader Enver Hoxha declared his support for Mao.

Further examples of disagreements during the Sino-Soviet split include:

 - 1958: Mao wanted the USSR to use their first satellite, Sputnik-1, to aid revolutionary efforts, but Khrushchev refused to risk nuclear conflict.
 - 1959: [China invaded Tibet](https://en.wikipedia.org/wiki/Annexation_of_Tibet_by_the_People's_Republic_of_China), but the USSR refused support and withdrew its support from the Chinese nuclear program by refusing to give them a prototype weapon.
 - 1962: China disagreed with the USSR in backing down and making in a deal in the [Cuban Missile Crisis](https://en.wikipedia.org/wiki/Cuban_Missile_Crisis), wanting them to support third world countries in their fight against communism.
 - 1963: China opposed the USSR signing of the [Partial Nuclear Test Ban Treaty](https://en.wikipedia.org/wiki/Partial_Nuclear_Test_Ban_Treaty) against nuclear weapons, sparking a fierce propaganda war.

### Cross-Strait relations

Mao never recognised Taiwan as an independent state.

In the [First Taiwan Strait Crisis](https://en.wikipedia.org/wiki/First_Taiwan_Strait_Crisis) from 1954 to 1955, the PLA bombed various islands near Taiwan and then seized the [Yijiangshan Islands](https://en.wikipedia.org/wiki/Yijiangshan_Islands) in a military conflict. This led to the [Formosa Resolution](https://en.wikipedia.org/wiki/Formosa_Resolution_of_1955) to be enacted by the US Congress — that US forces would defend Taiwan against any attack from the mainland.

In 1958, Mao ordered the PLA to attack the Taiwan-surrounding and -controlled islands of Kinmen and Matsu without discussion with the USSR. As the US prepared for war because of the Formosa Resolution, Mao stood down because he did not have USSR backup. In the aftermath, Khrushchev accused Mao of being a [Trotskyist](https://en.wikipedia.org/wiki/Trotskyism) who had lost all sense of reality.

### Sino-American relations

The US viewed China as an aggressive country with the objective of threatening the security of the non-communist states surrounding it. China viewed the US as their enemy.

!!! example
    The [Red Scares](https://en.wikipedia.org/wiki/Red_Scare) in the US and the anti-American and anti-capitalist propaganda in China (e.g., "Death to the American imperialists") meant that the two countries could not easily communicate diplomatically in public.

To "contain" communism in China, the US signed several treaties such as the [Southeast Asia Treaty Organization](https://en.wikipedia.org/wiki/Southeast_Asia_Treaty_Organization) and the [ANZUS Treaty](https://en.wikipedia.org/wiki/ANZUS) to ward off China. Additionally, they gave the Chinese seat at the UN to Taiwan, pushed allies to avoid entertaining diplomatic relations with Taiwan, supported countries that felt threatened by China, encouraged the split between the USSR and China, and implemented a trade embargo.

From 1970 onward, the two countries began to grow closer — China wanted a new strong ally as Sino-Soviet relations were deteriorating and the US wanted a way out of the Vietnam War.

Taking advantage of [ping-pong diplomacy](https://en.wikipedia.org/wiki/Ping-pong_diplomacy), the exchange of ping-pong players between the US and China, US Secretary of State Henry Kissinger went secretly to meet Chinese Premier Zhou Enlai.

The [**Shanghai Communiqué**](https://en.wikipedia.org/wiki/Shanghai_Communiqu%C3%A9) signed between the two countries on 28 February 1972 was a statement issued by both countries during US President Richard Nixon's visit to China — the first visit to the PRC by any US President — and began the normalisation of relations between them. Nixon described the visit as a mission for peace with the goal to re-establish communications after a generation of hostility, and agreements were reached to expand cultural, educational, and journalistic contracts.

### Historians

*Mao: a Biography* - Ross Terill (revisionist and somewhat sympathetic to Mao), 1995:

???+ quote
    Mao knew little of the world outside China, and nothing of the capitalist world… Yet Mao took a lively interest in the world beyond the Soviet Bloc during the early 1960s… It was as if the split with Russia in 1960 took a burden off the back of Chinese diplomacy. Instead of being junior partner in someone else’s show, Mao made China its own one-man show on the broadening stage of the Third World.

*Mao: Profiles in Power* - Shaun Breslin, 1998:

???+ quote
    Mao’s main objective in all of his foreign policy initiative from 1949 to 1976 was to safeguard China’s borders and restore China to its rightful position on the world stage. Mao had a traditional Sinocentrism: the notion that China is the central place in the world, and that only those who recognise and accept Chinese superiority can be considered to be civilised.

*Mao Zedong* - Maurice Meisner (sympathetic to socialist ideology and goals), 2007:

???+ quote
    Mao’s foreign policy clothed itself in revolutionary rhetoric, but was conservatively cautious in substance, based on narrow calculation of China’s national self-interest… In Mao’s view the Soviet Union posed a greater danger to China than did the United States.

## Resources

 - [IB History Syllabus](/resources/g11/ib-history-syllabus.pdf)
 - [Textbook: Origins and Development of Authoritarian and Single-Party States](/resources/g11/textbook-authoritarian-states.pdf)
 - [Textbook: Causes and Effects of 20th-Century Wars, Second Edition ](/resources/g11/textbook-cause-20-century-wars.pdf)
 - [Textbook: The Move to Global War](/resources/g11/textbook-move-global-war.pdf)
